@@ -3,9 +3,9 @@ use crate::currency::Cash;
 use crate::currency::converter::CurrencyConverter;
 use crate::formatting;
 use crate::localities::Country;
-use crate::taxes::{self, IncomeType, TaxExemption};
+use crate::taxes::{self, IncomeType, LtoDeductibleProfit, TaxExemption};
 use crate::time::DateOptTime;
-use crate::trades::calculate_price;
+use crate::trades::{self, RealProfit};
 use crate::types::{Date, Decimal};
 
 pub struct ForexTrade {
@@ -212,9 +212,9 @@ impl StockSell {
         let local_execution = |value| converter.convert_to_cash_rounding(
             self.execution_date, value, country.currency);
 
-        let mut purchase_cost = Cash::new(currency, dec!(0));
-        let mut purchase_local_cost = Cash::new(country.currency, dec!(0));
-        let mut deductible_purchase_local_cost = Cash::new(country.currency, dec!(0));
+        let mut purchase_cost = Cash::zero(currency);
+        let mut purchase_local_cost = Cash::zero(country.currency);
+        let mut deductible_purchase_local_cost = Cash::zero(country.currency);
 
         let mut fifo = Vec::new();
         let mut total_quantity = dec!(0);
@@ -236,10 +236,10 @@ impl StockSell {
                                 commission * source_quantity / self.quantity)?;
 
                             let source_local_profit = source_local_revenue
-                                .sub(source_local_commission).unwrap()
-                                .sub(source_total_local_cost).unwrap();
+                                - source_local_commission
+                                - source_total_local_cost;
 
-                            source_details.long_term_ownership_deductible.replace(LtoDeductible {
+                            source_details.long_term_ownership_deductible.replace(LtoDeductibleProfit {
                                 profit: std::cmp::max(dec!(0), source_local_profit.amount),
                                 years,
                             });
@@ -258,10 +258,10 @@ impl StockSell {
                 tax_free_quantity += source_quantity;
             }
 
-            purchase_cost.add_assign(source_total_cost).unwrap();
-            purchase_local_cost.add_assign(source_total_local_cost).unwrap();
+            purchase_cost += source_total_cost;
+            purchase_local_cost += source_total_local_cost;
             if !source_details.tax_exemption_applied {
-                deductible_purchase_local_cost.add_assign(source_total_local_cost).unwrap();
+                deductible_purchase_local_cost += source_total_local_cost;
             }
 
             fifo.push(source_details);
@@ -277,49 +277,30 @@ impl StockSell {
         let local_commission = local_conclusion(commission)?;
         let deductible_local_commission = local_conclusion(commission * taxable_ratio)?;
 
-        let total_cost = purchase_cost.add(converter.convert_to_cash_rounding(
-            self.conclusion_time.date, commission, currency)?).unwrap();
-        let total_local_cost = purchase_local_cost.add(local_commission).unwrap();
-        let deductible_total_local_cost = deductible_purchase_local_cost.add(deductible_local_commission).unwrap();
+        let total_cost = purchase_cost + converter.convert_to_cash_rounding(
+            self.conclusion_time.date, commission, currency)?;
+        let total_local_cost = purchase_local_cost + local_commission;
+        let deductible_total_local_cost = deductible_purchase_local_cost + deductible_local_commission;
 
-        let profit = revenue.sub(total_cost).unwrap();
-        let local_profit = local_revenue.sub(total_local_cost).unwrap();
-        let taxable_local_profit = taxable_local_revenue.sub(deductible_total_local_cost).unwrap();
+        let profit = revenue - total_cost;
+        let local_profit = local_revenue - total_local_cost;
+        let taxable_local_profit = taxable_local_revenue - deductible_total_local_cost;
 
-        let tax_without_deduction = Cash::new(country.currency, country.tax_to_pay(
-            IncomeType::Trading, tax_year, local_profit.amount, None));
-        let tax_to_pay = Cash::new(country.currency, country.tax_to_pay(
-            IncomeType::Trading, tax_year, taxable_local_profit.amount, None));
-        let tax_deduction = tax_without_deduction.sub(tax_to_pay).unwrap();
+        let tax_without_deduction = country.tax_to_pay(
+            IncomeType::Trading, tax_year, local_profit, None);
+        let tax_to_pay = country.tax_to_pay(
+            IncomeType::Trading, tax_year, taxable_local_profit, None);
+        let tax_deduction = tax_without_deduction - tax_to_pay;
         assert!(!tax_deduction.is_negative());
 
-        let real_tax_ratio = if profit.is_zero() {
-            None
-        } else {
-            Some(converter.convert_to(self.execution_date, tax_to_pay, profit.currency)? / profit.amount)
-        };
-
-        let real_profit = profit.sub(converter.convert_to_cash_rounding(
-            self.execution_date, tax_to_pay, currency)?).unwrap();
-
-        let real_profit_ratio = if purchase_cost.is_zero() {
-            None
-        } else {
-            Some(real_profit.div(purchase_cost).unwrap())
-        };
-
-        let real_local_profit = local_profit.sub(tax_to_pay).unwrap();
-        let real_local_profit_ratio = if purchase_local_cost.is_zero() {
-            None
-        } else {
-            Some(real_local_profit.div(purchase_local_cost).unwrap())
-        };
-
         Ok(SellDetails {
+            execution_date: self.execution_date,
+
             revenue,
             local_revenue,
             local_commission,
 
+            purchase_cost,
             purchase_local_cost,
             total_local_cost,
 
@@ -330,10 +311,6 @@ impl StockSell {
             tax_to_pay,
             tax_deduction,
 
-            real_tax_ratio,
-            real_profit_ratio,
-            real_local_profit_ratio,
-
             fifo,
         })
     }
@@ -354,12 +331,15 @@ pub struct StockSellSource {
 }
 
 pub struct SellDetails {
+    execution_date: Date,
+
     pub revenue: Cash,
     pub local_revenue: Cash,
     pub local_commission: Cash,
 
     // Please note that all of the following values can be zero due to corporate actions or other
     // non-trade operations:
+    pub purchase_cost: Cash,
     pub purchase_local_cost: Cash,
     pub total_local_cost: Cash,
 
@@ -370,18 +350,10 @@ pub struct SellDetails {
     pub tax_to_pay: Cash,
     pub tax_deduction: Cash,
 
-    pub real_tax_ratio: Option<Decimal>,
-    pub real_profit_ratio: Option<Decimal>,
-    pub real_local_profit_ratio: Option<Decimal>,
-
     pub fifo: Vec<FifoDetails>,
 }
 
 impl SellDetails {
-    pub fn long_term_ownership(&self) -> bool {
-        self.fifo.iter().any(|trade| trade.long_term_ownership_deductible.is_some())
-    }
-
     pub fn tax_exemption_applied(&self) -> bool {
         if self.fifo.iter().any(|trade| trade.tax_exemption_applied) {
             return true;
@@ -391,6 +363,12 @@ impl SellDetails {
         assert!(self.tax_deduction.is_zero());
         false
     }
+
+    pub fn real_profit(&self, converter: &CurrencyConverter) -> GenericResult<RealProfit> {
+        trades::calculate_real_profit(
+            self.execution_date, self.purchase_cost, self.purchase_local_cost,
+            self.profit, self.local_profit, self.tax_to_pay, converter)
+    }
 }
 
 pub struct FifoDetails {
@@ -406,7 +384,7 @@ pub struct FifoDetails {
     cost: PurchaseTotalCost,
 
     pub tax_exemption_applied: bool,
-    pub long_term_ownership_deductible: Option<LtoDeductible>,
+    pub long_term_ownership_deductible: Option<LtoDeductibleProfit>,
 }
 
 pub enum StockSourceDetails {
@@ -472,7 +450,7 @@ impl FifoDetails {
             StockSourceDetails::Trade {price, ..} if price.currency == currency => price,
             _ => {
                 let cost = self.cost(currency, converter)?;
-                calculate_price(self.quantity, cost)?
+                trades::calculate_price(self.quantity, cost)?
             },
         })
     }
@@ -574,10 +552,4 @@ impl PurchaseTransaction {
     fn new(date: Date, type_: PurchaseCostType, cost: Cash) -> PurchaseTransaction {
         PurchaseTransaction {date, type_, cost}
     }
-}
-
-#[allow(dead_code)] // FIXME(konishchev): Remove
-pub struct LtoDeductible {
-    profit: Decimal,
-    years: u32,
 }
\ No newline at end of file
