@@ -31,15 +31,9 @@ impl fmt::Display for InstrumentId {
     }
 }
 
-#[derive(Clone)]
+#[derive(Default, Clone)]
 pub struct InstrumentInternalIds(HashMap<String, String>);
 
-impl Default for InstrumentInternalIds {
-    fn default() -> InstrumentInternalIds {
-        InstrumentInternalIds(HashMap::new())
-    }
-}
-
 impl InstrumentInternalIds {
     fn get_symbol(&self, id: &str) -> GenericResult<&str> {
         Ok(self.0.get(id).ok_or_else(|| format!(concat!(
